.. _api_elem_values:

Element Value Decoding (:mod:`pydicom.values`)
==============================================

.. currentmodule:: pydicom.values

Element value decoding.

.. autosummary::
   :toctree: generated/

   convert_AE_string
   convert_ATvalue
   convert_DA_string
   convert_DS_string
   convert_DT_string
   convert_IS_string
   convert_numbers
   convert_OBvalue
   convert_OWvalue
   convert_PN
   convert_single_string
   convert_SQ
   convert_string
   convert_tag
   convert_text
   convert_TM_string
   convert_UI
   convert_UN
   convert_UR_string
   convert_value
